@@ -27,7 +27,7 @@
 #' @seealso \code{\link{imputedata}}
 #' @references 
 #'  Audigier, V. and Niang, N., Clustering with missing data: which equivalent for Rubin's rules? Advances in Data Analysis and Classification <doi:10.1007/s11634-022-00519-1>, 2022.
-#' @examples
+#' @examplesIf .Platform$OS.type=="windows"
 #' data(wine, package = "clusterMI")
 #' 
 #' require(parallel)
@@ -66,7 +66,8 @@ choosenbclust<-function (output, grid = 2:5, graph = TRUE, verbose = TRUE,
     nnodes.intern <- nnodes
   }
   if (nnodes.intern > 1) {
-    cl <- parallel::makeCluster(nnodes.intern, type = "PSOCK")
+    type.OS <-ifelse(.Platform$OS.type=="unix","FORK","PSOCK")
+    cl <- parallel::makeCluster(nnodes.intern, type = type.OS)
     parallel::clusterExport(cl, list("grid", "output",
                                      "imputedata",
                                      #appels imputedata
